==> knights-trinity-3.5.13.2.tar.xz: knights-trinity-3.5.13.2/knights/list_pgn.h <==
/***************************************************************************
                          list_pgn.h  -  description
                             -------------------
    begin                : Thu Dec 13 2001
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LIST_PGN_H
#define LIST_PGN_H

#include <tqvbox.h>
#include <tqstring.h>
#include "pgn.h"

/**
  *@author Troy Corbin Jr.
  */

class match_param;
class KStatusBar;
class KProgress;
class KListView;
class TQHBox;

class list_pgn : public TQVBox
{
	Q_OBJECT
  TQ_OBJECT
	public:
										list_pgn(TQWidget *parent=0, const char *name=0);
		void						setURL( TQString URL );
		void						setProgress( const int );
		TQString					URL( void )
												{ return myURL; }
										~list_pgn();


	signals:
		void						selected( const TQString&, const int& );

	protected slots:
		void						slot_selected( TQListViewItem *item );

	protected:
		void						timerEvent( TQTimerEvent * );

	private:
		TQString					myURL;
		TQHBox						*statusBox;
		KListView				*listView;
		KListView				*dummyView;
		KStatusBar			*status;
		KProgress				*progress;
		pgn							tmpPGN;
};

#endif

==> knights-trinity_14.1.0.orig.tar.xz: knights-trinity-14.1.0/knights/list_pgn.h <==
/***************************************************************************
                          list_pgn.h  -  description
                             -------------------
    begin                : Thu Dec 13 2001
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LIST_PGN_H
#define LIST_PGN_H

#include <tqvbox.h>
#include <tqstring.h>
#include "pgn.h"

/**
  *@author Troy Corbin Jr.
  */

class match_param;
class KStatusBar;
class KProgress;
class TDEListView;
class TQHBox;

class list_pgn : public TQVBox
{
	Q_OBJECT
  
	public:
										list_pgn(TQWidget *parent=0, const char *name=0);
		void						setURL( TQString URL );
		void						setProgress( const int );
		TQString					URL( void )
												{ return myURL; }
										~list_pgn();


	signals:
		void						selected( const TQString&, const int& );

	protected slots:
		void						slot_selected( TQListViewItem *item );

	protected:
		void						timerEvent( TQTimerEvent * );

	private:
		TQString					myURL;
		TQHBox						*statusBox;
		TDEListView				*listView;
		TDEListView				*dummyView;
		KStatusBar			*status;
		KProgress				*progress;
		pgn							tmpPGN;
};

#endif
